#!/bin/sh
#
# TCNV        Startup script for the TC bin.
#
# description: ThinCCo is a developer of Thin Client devices and Management
#              Software for server based computing.
# processname: tcnv
# config: /mnt/disc/hda/part5/config
# tcfile: /mnt/disc/hda/part5/config/.tcfiles

# Source global variables and function library.

. $TS_GLOBAL


quitNow ()
{
   exit 1
   return 0
}

# The .tcfiles conatains the list of files or directories
# to save. Paths must not be links.

CONFIG_DIR=$STORAGE_PATH/config
CONFIG_FILE=$CONFIG_DIR/.tcfiles
TC_HOME=$STORAGE_PATH/thinstation.profile

echo tcnv config running >> $LOGFILE

if [ ! -d $CONFIG_DIR ]; then
   mkdir $CONFIG_DIR
   if [ $? != 0 ]; then
       echo "Unable to create $CONFIG_DIR directory" >> $LOGFILE
       quitNow
   fi
fi

if [ ! -f "$CONFIG_FILE" ]; then #Create the default config file
   #Backup Home Directory
   echo $TC_HOME >> $CONFIG_FILE
fi
if [ ! -f "$CONFIG_FILE" ]; then
   echo "Unable to create $CONFIG_FILE" >> $LOGFILE
   quitNow
fi

rmcfg() { # Delete tcnv config files
        echo "Removing tcnv Configuration" >> $LOGFILE
        for F in `cat $CONFIG_FILE`
        do
           echo "Deleting $F" >> $LOGFILE
           ( cd /; rm -rf .$F >> $LOGFILE 2>&1 )
        done
        if [ $? != 0 ]; then
           echo "Delete failed, restoring last configuration." >> $LOGFILE
           restore
           return 1
          # quitNow
        fi
        return 0
}

restore() { #Restore tcnv config over TS config
        if [ -f "$CONFIG_DIR/.saved" ]; then
           echo "Restoring tcnv Configuration" >> $LOGFILE
           rmcfg
           if [ $? != 0 ]; then
              echo "Unable to remove home account. Exiting!!" >> $LOGFILE
              quitNow
           fi
           for F in `cat $CONFIG_FILE`
           do
              echo "Copy .$F TO /" >> $LOGFILE
              (cd $CONFIG_DIR; tar cf - .$F) | ( cd /; tar xpf -)
           done
           if [ $? != 0 ]; then
              echo "\nUnable to restore files in $CONFIG_FILE" >> $LOGFILE
              quitNow
           fi
        else
           echo "Save not current, skipping restore." >> $LOGFILE
        fi
        return 0
}

lastcfg() { #Function moves current config files to get ready for a new save
       echo "Saving last tcnv Configuration" >> $LOGFILE

       LASTCFG_DIR=$CONFIG_DIR/lastcfg
       if [ ! -d "$LASTCFG_DIR" ]; then # Create lastcfg if not there
          mkdir $LASTCFG_DIR
       else
          rm -rf $LASTCFG_DIR/* #Remove the old files in lastcfg
       fi

       for F in `cat $CONFIG_FILE`
       do
         echo "Copy .$F TO last config" >> $LOGFILE
         ( cd $CONFIG_DIR; tar cf - .$F ) | ( cd $LASTCFG_DIR; tar xpf -)
        if [ $? != 0 ]; then
            echo "Not Deleting files." >> $LOGFILE
         else
            echo "Removing files." >> $LOGFILE
           ( cd $CONFIG_DIR; rm -rf .$F )
           rm -rf CONFIG_DIR/.saved
         fi
       done
       return 0
}

save() { # Function Saves config file
        echo "Saving tcnv Configuration" >> $LOGFILE

        if [ -f "$CONFIG_DIR/.saved" ]; then
           lastcfg #move the current save files to lastcfg
        else
           echo "Save not current, skipping save of last config." >> $LOGFILE
        fi
        for F in `cat $CONFIG_FILE`
        do
           if [ ! -h $F ]; then
              tar cf - $F | ( cd $CONFIG_DIR; tar xpf -)
           else
              echo "Copying of links is not supported" >> $LOGFILE
           fi
        done
        if [ $? != 0 ]; then
           echo "\nUnable to save files in $CONFIG_FILE" >> $LOGFILE
           quitNow
        else
           touch $CONFIG_DIR/.saved
           echo "Save Complete!" >> $LOGFILE
           return 0
        fi
}

savefd() { # Function save Factory Default Settings

        #This is done only once after the first boot after a recovery.
        if [ ! -d "$CONFIG_DIR/fd" ] ; then
           echo "Saving tcnv Factory Default  Configuration" >> $LOGFILE
           mkdir "$CONFIG_DIR/fd"
           for F in `cat $CONFIG_FILE`
           do
              if [ ! -h $F ]; then
                 tar cf - $F | ( cd $CONFIG_DIR/fd; tar xpf -)
              else
                 echo "Copying of links is not supported" >> $LOGFILE
              fi
           done
           if [ $? != 0 ]; then
              echo "\nUnable to save files in $CONFIG_FILE" >> $LOGFILE
              quitNow
           else
              echo "Save of Factory Default Complete!" >> $LOGFILE
           fi
        else 
           echo "Save of Factory Default not needed." >> $LOGFILE
        fi
           return 0
}

killdaemons() {
  echo "Terminating device manager daemon" >> $LOGFILE
  for pid in `pidof dmc`; do
	kill $pid;
    sleep 1;
    [ -n `pidof dmc` ] && kill -9 `pidof dmc`
  done
}

fd() { # Restore Factory Defaults
        if [ -d "$CONFIG_DIR/fd" ] ; then
      	   killdaemons
           echo "Restoring Factory Default Configuration" >> $LOGFILE
           rm -rf $STORAGE_PATH/$TC_CONFIG
           cp $STORAGE_PATH/fd.cfg $STORAGE_PATH/$TC_CONFIG
           rmcfg
           if [ $? != 0 ]; then
              echo "Unable to remove home account. Exiting!!" >> $LOGFILE
              quitNow
           fi
           for F in `cat $CONFIG_FILE`
           do
              echo "Copy .$F TO /" >> $LOGFILE
              (cd $CONFIG_DIR/fd; tar cf - .$F) | ( cd /; tar xpf -)
           done
           if [ $? != 0 ]; then
              echo "\nUnable to restore Factory Defaults." >> $LOGFILE
              quitNow
           fi
           echo "Factory Defaults restored, rebooting..." >> $LOGFILE
           reboot
           # wait until system restarts or hang the whole thing if it goes comlpetely wrong
           sleep 99999
        else
           echo "Factory Default directory missing, skipping restore." >> $LOGFILE
        fi
        return 0
}


# If no arugements passed perform a restore and savefd.

# See how we were called
case "$1" in
  restore|"")
        #Run restore & savefd if no arguments are passed.
        savefd
        restore
        ;;
  save)
        save
        ;;
  savefd)
        #This is done only once after the first build
        savefd
        ;;
  fd)   
        #Restore Factory Defaults
        fd
        /bin/reboot
        ;;
  *)
        echo $"Usage: $prog {restore|save|savefd|fd|help}"
        quitNow
esac

quitNow

